==> alliance-5.0-20020701.tar.gz: alliance-5.0/xpat/src/XMX_event.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XPAT                           |
|                                                             |
| File    :                   Event.h                         |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                   04.12.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# ifndef XPAT_EVENT
# define XPAT_EVENT

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define XPAT_B1DN         0
# define XPAT_B3DN         1
# define XPAT_MOTION       2
# define XPAT_ENTER        3
# define XPAT_LEAVE        4

# define XPAT_KEY_UP       5
# define XPAT_KEY_DN       6
# define XPAT_KEY_LEFT     7
# define XPAT_KEY_RIGHT    8

# define XPAT_KEY_MORE     9
# define XPAT_KEY_LESS    10

# define XPAT_KEY_FIT     11
# define XPAT_KEY_REFRESH 12
# define XPAT_KEY_UNZOOM  13

# define XPAT_KEY_ZOOM_IN 14
# define XPAT_KEY_CENTER  15
# define XPAT_KEY_PAN     16

# define XPAT_RESCALE_MORE 17
# define XPAT_RESCALE_LESS 18

# define XPAT_MAX_EVENT_BUFFER 128

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
  
  extern void XpatInitializeEvent();
  extern void XpatDisplayEditMeasure();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/xpat/src/XMX_event.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                   XPAT                           |
|                                                             |
| File    :                   Event.h                         |
|                                                             |
| Authors :              Jacomme Ludovic                      |
|                                                             |
| Date    :                   04.12.96                        |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
|                         Include Files                       |
|                                                             |
\------------------------------------------------------------*/

# ifndef XPAT_EVENT
# define XPAT_EVENT

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define XPAT_B1DN         0
# define XPAT_B3DN         1
# define XPAT_MOTION       2
# define XPAT_ENTER        3
# define XPAT_LEAVE        4

# define XPAT_KEY_UP       5
# define XPAT_KEY_DN       6
# define XPAT_KEY_LEFT     7
# define XPAT_KEY_RIGHT    8

# define XPAT_KEY_MORE     9
# define XPAT_KEY_LESS    10

# define XPAT_KEY_FIT     11
# define XPAT_KEY_REFRESH 12
# define XPAT_KEY_UNZOOM  13

# define XPAT_KEY_ZOOM_IN 14
# define XPAT_KEY_CENTER  15
# define XPAT_KEY_PAN     16

# define XPAT_RESCALE_MORE 17
# define XPAT_RESCALE_LESS 18

# define XPAT_MAX_EVENT_BUFFER 128

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/
  
  extern void XpatInitializeEvent();
  extern void XpatDisplayEditMeasure();

# endif
